@@ -1,6 +1,6 @@
 %%%-------------------------------------------------------------------
 %%%
-%%% Copyright (C) 2002-2019 ProcessOne, SARL. All Rights Reserved.
+%%% Copyright (C) 2002-2020 ProcessOne, SARL. All Rights Reserved.
 %%%
 %%% Licensed under the Apache License, Version 2.0 (the "License");
 %%% you may not use this file except in compliance with the License.
@@ -25,12 +25,14 @@
 
 %% API
 -export([start/3, start_link/3, call/3, cast/2, reply/2, connect/1,
-	 stop/1, send/2, close/1, close/2, bind/2, establish/1, format_error/1,
+	 stop/1, stop_async/1, send/2, close/1, close/2, bind/2, establish/1, format_error/1,
 	 set_timeout/2, get_transport/1, change_shaper/2]).
 %% gen_server callbacks
 -export([init/1, handle_call/3, handle_cast/2, handle_info/2,
 	 terminate/2, code_change/3]).
 
+-deprecated([{stop, 1}]).
+
 %%-define(DBGFSM, true).
 -ifdef(DBGFSM).
 -define(FSMOPTS, [{debug, [trace]}]).
@@ -196,7 +198,7 @@ connect(Ref) ->
 -spec stop(pid()) -> ok;
 	  (state()) -> no_return().
 stop(Pid) when is_pid(Pid) ->
-    cast(Pid, stop);
+    stop_async(Pid);
 stop(#{owner := Owner} = State) when Owner == self() ->
     terminate(normal, State),
     try erlang:nif_error(normal)
@@ -205,6 +207,12 @@ stop(#{owner := Owner} = State) when Owner == self() ->
 stop(_) ->
     erlang:error(badarg).
 
+-spec stop_async(pid()) -> ok.
+stop_async(Pid) when is_pid(Pid) ->
+    cast(Pid, stop);
+stop_async(_) ->
+    erlang:error(badarg).
+
 -spec send(pid(), xmpp_element()) -> ok;
 	  (state(), xmpp_element()) -> state().
 send(Pid, Pkt) when is_pid(Pid) ->
@@ -445,13 +453,14 @@ handle_info({'$gen_event', closed}, State) ->
     noreply(process_stream_end({socket, closed}, State));
 handle_info(timeout, #{lang := Lang} = State) ->
     Disconnected = is_disconnected(State),
-    noreply(try callback(handle_timeout, State)
-	    catch _:{?MODULE, undef} when not Disconnected ->
-		    Txt = <<"Idle connection">>,
-		    send_pkt(State, xmpp:serr_connection_timeout(Txt, Lang));
-		  _:{?MODULE, undef} ->
-		    stop(State)
-	    end);
+    try noreply(callback(handle_timeout, State))
+    catch
+	_:{?MODULE, undef} when not Disconnected ->
+	    Txt = <<"Idle connection">>,
+	    noreply(send_pkt(State, xmpp:serr_connection_timeout(Txt, Lang)));
+	_:{?MODULE, undef} ->
+	    {stop, normal, State}
+    end;
 handle_info({'DOWN', MRef, _Type, _Object, _Info},
 	    #{socket_monitor := MRef} = State) ->
     noreply(process_stream_end({socket, closed}, State));
@@ -522,7 +531,9 @@ process_stream_end(_, #{stream_state := disconnected} = State) ->
 process_stream_end(Reason, State) ->
     State1 = send_trailer(State),
     try callback(handle_stream_end, Reason, State1)
-    catch _:{?MODULE, undef} -> stop(State1)
+    catch _:{?MODULE, undef} ->
+	stop_async(self()),
+	State1
     end.
 
 -spec process_stream(stream_start(), state()) -> state().
